<%@ WebHandler Language="C#" Class="AntiBotImage" %>

//===============================================================================================
//
// (c) Copyright Microsoft Corporation.
// This source is subject to the Microsoft Permissive License.
// See http://www.microsoft.com/resources/sharedsource/licensingbasics/sharedsourcelicenses.mspx.
// All other rights reserved.
//
//===============================================================================================

using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.SessionState;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Drawing.Imaging;
using System.Text;

/// <summary>
/// This Handler renders out a so called Anti-Bot image. It is used to prevent bots from making automatic entries in the guestbook.
/// The random text for the image is taken out of the session-variable "antibotimage". If this value is not present in the session, a empty gif is returned.
/// </summary>
public class AntiBotImage : IHttpHandler, IRequiresSessionState
{
    public bool IsReusable
    {
        get { return true; }
    }

    public enum FontWarpFactor
    {
        None,
        Low,
        Medium,
        High,
        Extreme
    }

    private FontWarpFactor _fontWarp;
    public FontWarpFactor FontWarp
    {
        get { return _fontWarp; }
        set { _fontWarp = value; }
    }

    private Random random;
    public Random Random
    {
        get { return random; }
        set { random = value; }
    }

    public void ProcessRequest(HttpContext context)
    {
        if(context.Session["antibotimage"] == null)
        {
            context.Session["antibotimage"] = generateRandomString(4).ToUpper();
        }
        this.random = new Random();
        GenerateImagePrivate(context.Session["antibotimage"].ToString(), 180, 50, "Verdana").Save(context.Response.OutputStream, ImageFormat.Jpeg);
    }

    private Bitmap GenerateImagePrivate(string Text, int width, int height, string fontFamilyName)
    {
        Font font;
        Bitmap bitmap = new Bitmap(width, height, PixelFormat.Format32bppArgb);
        using (Graphics graphics = Graphics.FromImage(bitmap))
        {
            graphics.SmoothingMode = SmoothingMode.AntiAlias;
            RectangleF rectF = new RectangleF(0f, 0f, width, height);
            Rectangle rect = new Rectangle(0, 0, width, height);
            HatchBrush smallConfettiBrush = new HatchBrush(HatchStyle.Cross, Color.LightGray, Color.White);
            graphics.FillRectangle(smallConfettiBrush, rect);
            float previousWidth = 0f;
            float size = Convert.ToInt32((height * 0.8));
            while (true)
            {
                font = new System.Drawing.Font(fontFamilyName, size, FontStyle.Bold);
                SizeF textSize = graphics.MeasureString(Text, font);
                if (textSize.Width <= width)
                {
                    break;
                }
                if (previousWidth > 0f)
                {
                    int estimatedSize = Convert.ToInt32(((textSize.Width - width) / (previousWidth - textSize.Width)));
                    if (estimatedSize > 0)
                    {
                        size -= estimatedSize;
                    }
                    else
                    {
                        size -= 1f;
                    }
                }
                else
                {
                    size -= 1f;
                }
                previousWidth = textSize.Width;
            }
            size += 4f;

            font = new System.Drawing.Font(fontFamilyName, size, FontStyle.Bold);
            StringFormat format = new StringFormat();
            format.Alignment = StringAlignment.Center;
            format.LineAlignment = StringAlignment.Center;

            GraphicsPath textPath = new GraphicsPath();
            textPath.AddString(Text, font.FontFamily, (int)font.Style, font.Size, rect, format);
            if (this.FontWarp != FontWarpFactor.None)
            {
                int warpDivisor = 0;
                switch (this._fontWarp)
                {
                    case FontWarpFactor.Low:
                        warpDivisor = 6;
                        break;

                    case FontWarpFactor.Medium:
                        warpDivisor = 5;
                        break;

                    case FontWarpFactor.High:
                        warpDivisor = 4;
                        break;

                    case FontWarpFactor.Extreme:
                        warpDivisor = 3;
                        break;
                }
                int heightRange = Convert.ToInt32((((double)rect.Height) / ((double)warpDivisor)));
                int widthRange = Convert.ToInt32((((double)rect.Width) / ((double)warpDivisor)));
                PointF point1 = this.RandomPoint(0, widthRange, 0, heightRange);
                PointF point2 = this.RandomPoint(rect.Width - (widthRange - Convert.ToInt32(point1.X)), rect.Width, 0, heightRange);
                PointF point3 = this.RandomPoint(0, widthRange, rect.Height - (heightRange - Convert.ToInt32(point1.Y)), rect.Height);
                PointF point4 = this.RandomPoint(rect.Width - (widthRange - Convert.ToInt32(point3.X)), rect.Width, rect.Height - (heightRange - Convert.ToInt32(point2.Y)), rect.Height);
                PointF[] points = new PointF[] { point1, point2, point3, point4 };
                Matrix matrix = new Matrix();
                matrix.Translate(0f, 0f);
                textPath.Warp(points, rectF, matrix, WarpMode.Perspective, 0f);
            }
            HatchBrush largeConfettiBrush = new HatchBrush(HatchStyle.LargeConfetti, Color.LightGray, Color.DarkGray);
            graphics.FillPath(largeConfettiBrush, textPath);

            int maxDimension = Math.Max(rect.Width, rect.Height);
            int steps = Convert.ToInt32((((double)(rect.Width * rect.Height)) / 30));
            for (int i = 0; i <= steps; i++)
            {
                graphics.FillEllipse(largeConfettiBrush, this.random.Next(rect.Width), this.random.Next(rect.Height), this.random.Next(Convert.ToInt32((((double)maxDimension) / 50))), this.random.Next(Convert.ToInt32((((double)maxDimension) / 50))));
            }
            font.Dispose();
            largeConfettiBrush.Dispose();
            graphics.Dispose();
        }
        return bitmap;
    }

    private PointF RandomPoint(int xmin, int xmax, int ymin, int ymax)
    {
        return new PointF(this.random.Next(xmin, xmax), this.random.Next(ymin, ymax));
    }

    private string generateRandomString(int size)
    {
        StringBuilder builder = new StringBuilder();
        Random random = new Random();
        char ch;
        for (int i = 0; i < size; i++)
        {
            ch = Convert.ToChar(Convert.ToInt32(Math.Floor(26 * random.NextDouble() + 65)));
            builder.Append(ch);
        }
        return builder.ToString();
    }
}
